@@ -1,4 +1,4 @@
-//  $Id: font_test_screen.hpp 3116 2007-09-09 17:41:20Z grumbel $
+//  $Id: font_test_screen.hpp 3265 2007-09-30 16:07:08Z grumbel $
 //
 //  Pingus - A free Lemmings clone
 //  Copyright (C) 2007 Ingo Ruhnke <grumbel@gmx.de>
@@ -20,7 +20,7 @@
 #ifndef HEADER_FONT_TEST_SCREEN_HPP
 #define HEADER_FONT_TEST_SCREEN_HPP
 
-#include "gui/screen.hpp"
+#include "screen/screen.hpp"
 #include "font.hpp"
 
 /** */
