@@ -1,4 +1,4 @@
-//   $Id: pingus_main.cpp 3232 2007-09-22 15:58:45Z grumbel $
+//   $Id: pingus_main.cpp 3404 2007-10-30 08:39:56Z grumbel $
 //    ___
 //   | _ \                         |      ,--.    |
 //   |   /_  _ _  ___  _   _  ___  |   ,-/ o  \   |
@@ -35,6 +35,21 @@
 #include "string_util.hpp"
 #include "sexpr_file_reader.hpp"
 
+#if defined(__APPLE__)
+/* Can't use the include, some type names conflict.
+#include <CoreFoundation/CoreFoundation.h>
+*/
+extern "C" {
+       typedef unsigned char UInt8;
+       typedef void* CFTypeRef;
+       typedef CFTypeRef CFURLRef;
+       CFURLRef CFBundleGetMainBundle(void);
+       CFURLRef CFBundleCopyResourcesDirectoryURL(CFTypeRef);
+       bool CFURLGetFileSystemRepresentation(CFURLRef, bool, UInt8*, int);
+       void CFRelease(CFTypeRef);
+}
+#endif
+
 #include "SDL.h"
 
 #ifdef ENABLE_BINRELOC
@@ -45,7 +60,7 @@
 #include "tinygettext/dictionary_manager.hpp"
 #include "command_line.hpp"
 
-#include "gui/screen_manager.hpp"
+#include "screen/screen_manager.hpp"
 #include "dummy_screen.hpp"
 // #include "gui/input_debug_screen.hpp"
 #include "path_manager.hpp"
@@ -171,7 +186,7 @@ PingusMain::apply_args()
       std::cout << "========================" << std::endl;
       std::set<std::string> lst = dictionary_manager.get_languages();
       for (std::set<std::string>::iterator i = lst.begin(); i != lst.end(); ++i)
-        std::cout << TinyGetText::get_language_def(*i).name << " (" << *i << ")" << std::endl;
+        std::cout << TinyGetText::get_language_def(*i)->name << " (" << *i << ")" << std::endl;
 
       std::cout << "\nLanguages can be used via:\n\n    pingus --language de\n" << std::endl; 
 
@@ -203,7 +218,7 @@ PingusMain::apply_args()
 
   // Misc
   if (options.language.is_set())
-    dictionary_manager.set_language(options.language.get());
+    dictionary_manager.set_current_dictionary(options.language.get());
 
   if (options.auto_scrolling.is_set())
     auto_scrolling = options.auto_scrolling.get();
@@ -264,7 +279,7 @@ PingusMain::parse_args(int argc, char** argv)
                   _("Disable music"));
 
   argp.add_group("Language Options:");
-  argp.add_option(364, "language", "LANG",
+  argp.add_option('L', "language", "LANG",
                   _("Select language to use with Pingus"));
   argp.add_option(365, "list-languages", "",
                   _("List all available languages"));
@@ -510,7 +525,7 @@ PingusMain::parse_args(int argc, char** argv)
             cmd_options.font.set(true);
             break;
 
-          case 364: // language
+          case 'L': // language
             cmd_options.language.set(argp.get_argument());
             break;
 
@@ -612,7 +627,12 @@ PingusMain::print_greeting_message()
   std::cout << std::endl;
 
   std::cout << "data path:               " << path_manager.get_base_path() << std::endl;
-  std::cout << "language:                " << dictionary_manager.get_dictionary().get_language().name << std::endl;
+  std::cout << "language:                " 
+            << dictionary_manager.get_dictionary().get_language()->name 
+            << " ("
+            << dictionary_manager.get_dictionary().get_language()->code 
+            << ")"
+            << std::endl;
 
   Fonts::encoding = StringUtil::to_lower(dictionary_manager.get_dictionary().get_charset());
   std::cout << "font encoding:           " << Fonts::encoding << std::endl;
