@@ -1,4 +1,4 @@
-//  $Id: solid_color_background.cpp 2986 2007-08-17 16:20:09Z grumbel $
+//  $Id: solid_color_background.cpp 3265 2007-09-30 16:07:08Z grumbel $
 //
 //  Pingus - A free Lemmings clone
 //  Copyright (C) 2000 Ingo Ruhnke <grumbel@gmx.de>
@@ -17,7 +17,7 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-#include "../gui/display.hpp"
+#include "../display/display.hpp"
 #include "../display/scene_context.hpp"
 #include "solid_color_background.hpp"
 
